// FILE: src/config/config.js
(function () {

	var ZeedhiApp = angular.module("ZeedhiApp");

	window.templateUrls = window.templateUrls || [];
	var packageName = 'zh-description';

	var hasPackageRegistered = window.templateUrls.some(function (templateUrl) {
		return templateUrl.package === packageName;
	});

	if (!hasPackageRegistered) {
		window.templateUrls.push({
			'package': packageName,
			'baseUrl': './bower_components/' + packageName + '/dist/templates/'
		});
	}
})();

// FILE: src/controllers/DescriptionController.js
function DescriptionController($scope) {

    var field = $scope.field;

    /**
     * Gives the component's header.
     */
    this.getHeader = function() {
        return field.head;
    };

    /**
     * Determines whereas the field has a header.
     * @returns {String} The component header.
     */
    this.hasHeader = function() {
        return this.getHeader() === undefined ? false : true;
    };

    /**
     * Gives the component's body.
     * @param {Boolean} isJson - Param telling if the text is an unescaped json
     */
    this.getBody = function() {
        return field.body;
    };

    /**
     * Determines whereas the field has a body.
     * @returns {String} The component body.
     */
    this.hasBody = function() {
        return this.getBody() === undefined ? false : true;
    };
}

// FILE: src/register/descriptionRegister.js
(function () {

	Configuration(registerDescriptionDecoders);

	function registerDescriptionDecoders(DecodeValueFieldService, decodeTemplateFieldService) {
		decodeTemplateFieldService.registerViewTemplate(
			"zh-description#field/description.html",
			"zh-description#field/description.html"
		);

		DecodeValueFieldService.register(
			"zh-description#field/description.html",
			descriptionValueDecoder()
		);
	}

	function descriptionValueDecoder() {
		return function (field, fieldRow) {
			field.text = field.text || '';
			field.title = field.title || '';
			return field.title;
		};
	}

})();
